\NeedsTeXFormat{LaTeX2e}
\ProvidesClass{ecmet}[2004/02/21 For Econometrics Class Notes in AMS-LaTeX]

% Copyright Hans G. Ehrbar

% This program can redistributed and/or modified under the terms
% of the LaTeX Project Public License Distributed from CTAN
% archives in directory macros/latex/base/lppl.txt; either
% version 1 of the License, or (at your option) any later version.

\newif\ifEcmet@monochrome %for black and white printouts.
%presently all printouts will be b/w, but if I get
%a color printer this may no longer be true.

\newif\ifEcmet@pdftex \Ecmet@pdftextrue %will be turned off by dvips
%If pdflatex has a bug I may need latex sometimes, and vice versa

\newif\ifEcmet@devel %development version, prints also the hidden stuff

\newif\ifEcmet@answers\Ecmet@answerstrue %will be switched off by noanswer

\newif\ifEcmet@screen %version for screen reading

%\newif\ifEcmet@uspaperformat %the default is a4

%The following booleans are accessible to the user;
%eventually I may want to do it using the comment package

\newif\ifexam

\newif\ifsingular\singulartrue


\newif\ifvariant
%boolean to pass to the picture in ndfcm.tex and cbbpic1.tex
%and perhaps other pictures as well



\DeclareOption{monochrome}{%
   \Ecmet@monochrometrue
   \PassOptionsToPackage{monochrome}{randvar}%
   \PassOptionsToPackage{monochrome}{color}%
}

%\DeclareOption{exam}{\examtrue}

\DeclareOption{exam}{%
  \examtrue
   \PassOptionsToPackage{exam}{hidden}%
}

\DeclareOption{noanswer}{%
 \Ecmet@answersfalse
   \PassOptionsToPackage{noanswer}{mathprob}%
}

\DeclareOption{devel}{%
   \PassOptionsToClass{draft}{amsbook}%
   \PassOptionsToClass{draft}{amsart}%
   \PassOptionsToPackage{draft}{randvar}%
   \PassOptionsToPackage{draft}{hidden}%
   \Ecmet@develtrue
}


\DeclareOption{screen}{%
   \PassOptionsToPackage{screen}{choosize}%
	\Ecmet@screentrue
     %\PassOptionsToClass{12pt}{book}%
     %\PassOptionsToClass{12pt}{amsart}%
}

\DeclareOption{uspaperformat}{
   \PassOptionsToPackage{uspaperformat}{choosize}%
     %\Ecmet@uspaperformattrue
	%\ifEcmet@afourpaper\errmessage{! You cannot declare uspaper and a4paper at the same time}\fi
}

%\DeclareOption{a4paper}{
%     \Ecmet@afourpapertrue
%	\ifEcmet@uspaper\errmessage{! You cannot declare uspaper and a4paper at the same time}\fi
%}

\DeclareOption{twoup}{
   \PassOptionsToPackage{twoup}{choosize}%
}


%Maybe I should not even bother with this
%\DeclareOption{twocolumn}{
%     \Ecmet@twocolumntrue
%     \PassOptionsToClass{twocolumn,12pt}{book}%
%     \PassOptionsToClass{twocolumn,12pt}{amsart}%
%}


%\DeclareOption{pdftex}{
%     \Ecmet@pdftextrue
%     \PassOptionsToClass{pdftex}{book}%
%}

\DeclareOption{dvips}{
     \Ecmet@pdftexfalse
     \PassOptionsToClass{dvips}{amsbook}%
     \PassOptionsToClass{dvips}{amsart}%
}

\ProcessOptions\relax


\ifexam
\LoadClass[psamsfonts]{amsart}
\renewcommand{\datename}{Date of exam}
\else %i.e. examfalse
\LoadClass[psamsfonts]{amsbook}
%\LoadClass[openany,psamsfonts,12pt]{amsbook}
%\LoadClass[openany]{book}
\fi

%Ther following is not necessary if I use amsbook
%\RequirePackage{amsmath,amsthm}


\ifEcmet@pdftex
\RequirePackage[pdftex,dvipsnames]{color}
\RequirePackage{pdfcolmk}
\pdfcompresslevel=9
\else
\RequirePackage[dvips]{color}
\fi


\RequirePackage{hidden}
\RequirePackage{mathprob}
\ifexam\RequirePackage{xamprob}\fi

%%I am using this to put clearpages in, so that figures will show up.
%%I'd like to get rid of it again:
%%\newcommand{\screenpaper}[2]{\ifEcmet@screen #1\else #2\fi}
%%Replaced with  \ifdim\textheight<16275169sp\clearpage\fi


\RequirePackage[psamsfonts]{eurm}

\RequirePackage{cmmib57}




%Fixed font for the figures:
%The following comes from the Graphics Companion p. 16
%and there is also sth very similar in fntguide.pdf Section 2.5
\DeclareFixedFont{\fiverm}{OT1}{cmr}{m}{n}{5}
%\DeclareFixedFont{\ninerm}{OT1}{cmr}{m}{n}{9}
%Maybe I should declare other fonts too,
%so that I can make dots and other symbols of various
%sizes in the picture environment,
%in which the dimensions are static.
%See p 7 of the amsfonts guide.

\RequirePackage{verbatim,randvar,mark,boxes,arca}
%\RequirePackage{randvar,hodir,levels,mathmac,mark,fullpage}
%\RequirePackage{verbatim,randvar,mark,boxes,arca,histogr}
%\RequirePackage{verbatim,randvar,hodir,mark,fullpage}

%\ifEcmet@devel\RequirePackage{showlabels}\fi %is not very pretty


\gdef\recatcode{\catcode35=12\catcode36=12\catcode94=12\catcode95=12\catcode124=12\catcode126=12\relax}
%The relax is important
%The text to be recatcoded cannot be the argument;
%once it is read as argument the catcodes are already fixed
\gdef\Rcommand{\ttfamily\recatcode}

%Moved to hidden.sty
%\newcommand{\IgnoreCommentCharacter}{\catcode`\%=9\relax}
%\newcommand{\RestoreCommentCharacter}{\catcode`\%=14\relax}


%from /usr/lib/texmf/generic/misc/texnames
    \def\AmS{$\mathcal{A}$\kern-.1667em\lower.5ex\hbox
        {$\mathcal{M}$}\kern-.125em$\mathcal{S}$}






\newcommand{\swallow}[1]{\relax}

%%Obsoleted by ecmtroot.sty:
%%\newcommand{\ecmtroot}{~/dpkg/ECMET/debian/ecmet/usr/share/ecmet}
%% Uncomment above line
%% and comment the next line
%% if you want to point to exploded directory:
%%\newcommand{\ecmtroot}{/usr/share/ecmet}


%\newcommand{\lecmetdir}{/home/econ/dpkg/ECMET/debian/ecmet/usr/share/ecmet/private}
%\newcommand{\lecmetdir}{/home/econ/ehrbar/ha/te/lecmet}
%\newcommand{\Rpackdir}{/usr/lib/R/library/ecmet}
%\newcommand{\Rsourcedir}{/home/econ/dpkg/ECMET/debian/ecmet/usr/share/ecmet/usr/lib/R/library/ecmet}
\newcommand{\Rsourcedir}{/usr/share/ecmet/usr/lib/R/library/ecmet}
%% I can specify Rsourcedir because I am building the
%% R source for ecmet on the same computer;
%% but what if this is public?
%% I will have to specify my tar ball in such a way
%% that it picks out the appropriate files
%% from the installed R-package.
%% Is this a good idea?
%% If I do this, then I should uncomment \Rpackdir
%% and change globally first \Rsourcedir/inst
%% and then \Rsourcedir  into \Rpackdir

%%inputmacro to discover an unended question environment; chge Question to question
%\renewcommand{\inputm@cro}[2]{\ifexam\else\ifnum\hidenestlevel>0\relax
%\errmessage{#2.entered.in.shape}\fi\fi\typeout{!!!Here}\end{thm}\input{#1/#2}}


%\inputm@cro is defined in hidden.sty

\RequirePackage[exploded]{ecmtroot}

%%\newcommand{\ecmetinput}[1]{\inputm@cro\ecmtroot{#1}}
%%\newcommand{\lecmetinput}[1]{\inputm@cro\lecmetdir{#1}}

%%\newcommand{\drecmetinput}[1]{\ifEcmet@devel\ecmetinput{#1}\fi}
%%\newcommand{\dlecmetinput}[1]{\ifEcmet@devel\lecmetinput{#1}\fi}

%fincmetinput only inputs the file if it is final mode, and if it is an exam:
%I used that as a hack when the whole manuscript was too large for pdftex
%\newcommand{\fincmetinput}[1]{\ifEcmet@devel\ifexam\ecmetinput{#1}\fi\else\ecmetinput{#1}\fi}

%Fincmetinput disabled
%%\newcommand{\fincmetinput}[1]{\ecmetinput{#1}}


%\renewcommand{\ecmetinput}[1]{\ifexam\else\ifnum\hidenestlevel>0\relax
%\errmessage{#1.entered.in.shape}\fi\fi\typeout{!!!Here}\end{thm}\input{\ecmetroot/#1}}

\newcommand{\Marriott}[1]{{\color{Attn}#1}}

%want to make this better;
\def\fillin#1{\framebox[11mm]{\rule[-2mm]{0mm}{7mm}}}

%I should have macros for hidden questions,
%which are not draft but which can used in exams,
%and for important questions which are never in the shade.

%% \theoremstyle{plain}   %% This is the default
%\begingroup % Confine the \theorembodyfont command
%\theorembodyfont{\sl}
\newtheorem{bigthm}{Theorem}   % Numbered separately, as A, B, etc.
\newtheorem{thm}{Theorem}[section]   % Numbered within each section
\newtheorem{cor}[thm]{Corollary}     % Numbered along with thm
\newtheorem{lem}[thm]{Lemma}         % Numbered along with thm
\newtheorem{prop}[thm]{Proposition}  % Numbered along with thm
%\newtheorem{ax}{Axiom}
%\endgroup

%%% We need to do the following outside of any group,
%%% since it's not \global:
\renewcommand{\thebigthm}{\Alph{bigthm}}  % Number as "Theorem A."


\theoremstyle{definition}
\newtheorem{defn}[thm]{Definition}   % Numbered along with thm

\theoremstyle{remark}
\newtheorem{rem}[thm]{Remark}        % Numbered along with thm
%\newtheorem{ex}[thm]{Example}        % Numbered along with thm
%\newtheorem*{notation}{Notation}
%\renewcommand{\thenotation}{}  % to make the notation
                               % environment unnumbered
   %But I think the star already did this

%\newtheorem*{terminology}{Terminology}
%\renewcommand{\theterminology}{}  % to make the terminology
                                  % environment unnumbered
    %But I think star already did this

%%%%Now my own:

%%% So far only used once in sorams:
\newtheorem*{assumption}{Assumption}


%The following is in linone and linxamp
%vtable is only used in linxamp:
\RequirePackage{vtable}
\global\let\beginproofappendix\relax
\global\let\endproofappendix\relax
\global\let\companionfile\relax
%Maybe the following should go into randvar?
\gdef\vel#1#2{\langle\covec{#1}\swallow{M},#2\rangle}
\gdef\VEL#1{\langle\covec{#1}\rangle}
%The following would be more elegant with
%a new environment
\gdef\longlist#1{\begin{center}
\begin{tabular}{|c|c|c|c|c|c|c|c|c|c|c|c|}
${\coma{t}}\swallow{qm}$&$\zm$&${\covec{t}}\swallow{q}$&$\cTheta\swallow{qQ}$&$\yn$&${\coma{h}}\swallow{nm}$&${\coma{v}}\swallow{mM}$&${\covec{v}}\swallow{m}$&${\coma{u}}\swallow{mj}$&${\coma{j}}\swallow{qn}$&${\coma{q}}\swallow{jq}$&${\coma{k}}\swallow{mo}$\\
\hline #1\end{tabular}  \end{center}}


\gdef\shortlist#1{\begin{center}
\begin{tabular}{|c|c|c|c|}
${\coma{s}}\swallow{qn\vert m}$&$\zm$&${\covec{s}}\swallow{QN}$&$\cSigma\swallow{QN\vert QN}$\\
\hline #1\end{tabular}  \end{center}}

%end of stuff for linone and linxamp


%%% The following causes equations to be numbered within sections:
\ifexam\else\numberwithin{equation}{section}\numberwithin{section}{chapter}\fi


\newenvironment{partrix}{\begin{bmatrix}}{\end{bmatrix}}

\newenvironment{sbmatrix}
{\left[\begin{smallmatrix}}
{\end{smallmatrix}\right]}

\newenvironment{spartrix}
{\left[\begin{smallmatrix}}
{\end{smallmatrix}\right]}



%crcomments are given in a different color
%because they are experimental,
%and I want them to start in the first line
%so that I have the option to suppress them:
\newenvironment{CRCOMMENT}%
{\color[named]{Blue}}{}





%%I have to fix 
%%threadpage is for splitting the printout in portions
%
%\newcount\threadpage\global\threadpage=1
%\newcount\threadcount\global\threadcount=1
%\gdef\threadpoint#1{\ifnum\threadcount>9\errmessage{Too.many.threadpoints}\fi\typeout{! threadpoint -pp \the\threadpage:\the\count0\space\space -o \ifemclass\ifbilingual akmk\else akmc\fi\else akml\fi_\the\threadcount.ps \jobname;
%}
%\global\threadpage=\count0\global\advance\threadpage#1\relax
%\global\advance\threadcount1\relax}


%The following macros allow me to use the same code
%for singular and nonsingular assumptions.
%I am doing this right now in chapter \ref{sec:lincond}
%but this should be extended to other cases too.

\newcommand{\gorinv}{\ifsingular\g\else^{-1}\fi}
\newcommand{\singlabel}[1]{\ifsingular\label{#1-sing}\else\label{#1}\fi}
\newcommand{\singref}[1]{\ifsingular\ref{#1-sing}\else\ref{#1}\fi}
\newcommand{\singeqref}[1]{\ifsingular\eqref{#1-sing}\else\eqref{#1}\fi}
%The mathecon should be done in terms of singular too
\gdef\mathecon#1#2{\ifEcmet@devel\texttt{\color{Attn}<math}{#1}\texttt{\color{Attn}>econ<}{#2}\texttt{\color{Attn}>}\else{#2}\fi}
%\gdef\beginmath{\ifexam\else\ifEcmet@devel\texttt{\color{Attn}beginmath}\else\escape\fi\fi}
%\gdef\endmath{\ifexam\else\ifEcmet@devel\texttt{\color{Attn}endmath}\else\unescape\fi\fi}
%\gdef\beginecon{\ifexam\else\ifEcmet@devel\texttt{\color{Attn}beginecon}\fi\fi}
%\gdef\endecon{\ifexam\else\ifEcmet@devel\texttt{\color{Attn}endecon}\fi\fi}



%at the very end load hyperref.  Have fit if screen, and fitBH otherwise
%I eliminated backref in devel mode because of memory overflow
\ifEcmet@pdftex

%I am loading hyperref only if running pdftex
%But I am loading it with 4 different specifications
%For screen I need Fit, for paper I need fitBH
%for final I have pagebackref on,  but for devel it leads to mem overflow

\ifEcmet@devel
\ifEcmet@screen

  \RequirePackage[pdftex,%
             %pagebackref,% for devel pagebackref off bec overflow
             pdfpagemode=none,%
             colorlinks,%
             %pdfmenubar=false,%
             %pdftoolbar=false,%
             bookmarks=true,%
             bookmarksnumbered=false,%
             pdffitwindow=true,pdfcenterwindow=true,%
             %pdfwindowui=false,%
             %menucolor=menucolor,%
             pdfview=Fit,pdfstartview=Fit]{hyperref}

\else

  \RequirePackage[pdftex,%
             %pagebackref,%
             pdfpagemode=none,%
             colorlinks,%
             %pdfmenubar=false,%
             %pdftoolbar=false,%
             bookmarks=true,%
             bookmarksnumbered=false,%
             pdffitwindow=true,pdfcenterwindow=true,%
             %pdfwindowui=false,%
             %menucolor=menucolor,%
             pdfview=FitBH,pdfstartview=FitBH]{hyperref}

\fi %end of ifEcmet@screen

\else

\ifEcmet@screen

  \RequirePackage[pdftex,%
             pagebackref,%
             pdfpagemode=none,% does not show bookmarks on opening
             colorlinks,%
             %pdfmenubar=false,%
             %pdftoolbar=false,%
             bookmarks=true,%
             bookmarksnumbered=false,%
             pdffitwindow=true,pdfcenterwindow=true,%
             %pdfwindowui=false,%
             %menucolor=menucolor,%
             pdfview=Fit,pdfstartview=Fit]{hyperref}

\else  %%Here it still declares pdftex, this is not always right



  \RequirePackage[pdftex,%
             pagebackref,%
             pdfpagemode=none,%
             %colorlinks,% as long as all my print is b/w. colorlinks wont show
             %pdfmenubar=false,%
             %pdftoolbar=false,%
             bookmarks=true,%
             bookmarksnumbered=false,%
             pdffitwindow=true,pdfcenterwindow=true,%
             %pdfwindowui=false,%
             %menucolor=menucolor,%
             pdfview=FitBH,pdfstartview=FitBH]{hyperref}

\fi

\fi %end of ifEcmet@devel

 \RequirePackage{nohyper}

\else  %Now the case that pdftex is not loaded


\let\nohyper\relax
\newcommand{\href}[2]{#2}

\fi  %end of ifEcmet@pdftex


\RequirePackage{choosize}


%I added some extra \space since otherwise TeX seemed confused
\typeout{\jobname\space\space\ifEcmet@devel devel \else final \fi\space\ifEcmet@answers \else no answer \fi\ifEcmet@monochrome\space monochrome \fi\ifexam\space exam \fi\ifEcmet@pdftex\else\space dvips \fi}
\batchmode
